@@ -21,7 +21,7 @@
 
 /*! \file conf_cluster.h
  * \brief Implements cluster {} block configuration management.
- * \version $Id: conf_cluster.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: conf_cluster.h 10005 2021-06-28 12:10:15Z michael $
  */
 
 #ifndef INCLUDED_conf_cluster_h
@@ -53,4 +53,4 @@ extern const dlink_list *cluster_get_list(void);
 extern void cluster_clear(void);
 extern struct ClusterItem *cluster_make(void);
 extern void cluster_distribute(const void *, const char *, unsigned int, unsigned int, const char *, ...);
-#endif
+#endif  /* INCLUDED_conf_cluster_h */
