@@ -22,7 +22,7 @@
 
 /*! \file conf_db.h
  * \brief Includes file utilities for database handling
- * \version $Id: conf_db.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: conf_db.h 10005 2021-06-28 12:10:15Z michael $
  */
 
 #ifndef INCLUDED_conf_db_h
@@ -57,4 +57,4 @@ extern void save_xline_database(const char *);
 extern void load_resv_database(const char *);
 extern void save_resv_database(const char *);
 extern void save_all_databases(void *);
-#endif
+#endif  /* INCLUDED_conf_db_h */
