@@ -21,7 +21,7 @@
 
 /*! \file conf_pseudo.h
  * \brief Handles with pseudo commands/service aliases.
- * \version $Id: conf_pseudo.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: conf_pseudo.h 10005 2021-06-28 12:10:15Z michael $
  */
 
 #ifndef INCLUDED_conf_pseudo_h
@@ -39,8 +39,6 @@ struct PseudoItem
 };
 
 extern const dlink_list *pseudo_get_list(void);
-extern void pseudo_register(const char *, const char *,
-                            const char *, const char *,
-                            const char *);
+extern void pseudo_register(const char *, const char *, const char *, const char *, const char *);
 extern void pseudo_clear(void);
 #endif  /* INCLUDED_conf_pseudo_h */
