@@ -21,7 +21,7 @@
 
 /*! \file conf_service.h
  * \brief Implements service {} block configuration management.
- * \version $Id: conf_service.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: conf_service.h 10005 2021-06-28 12:10:15Z michael $
  */
 
 #ifndef INCLUDED_conf_service_h
@@ -37,4 +37,4 @@ extern const dlink_list *service_get_list(void);
 extern void service_clear(void);
 extern struct ServiceItem *service_make(void);
 extern const struct ServiceItem *service_find(const char *, int (*)(const char *, const char *));
-#endif
+#endif  /* INCLUDED_conf_service_h */
