@@ -21,7 +21,7 @@
 
 /*! \file conf_shared.h
  * \brief Implements shared {} block configuration management.
- * \version $Id: conf_shared.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_conf_shared_h
@@ -55,4 +55,4 @@ extern const dlink_list *shared_get_list(void);
 extern void shared_clear(void);
 extern struct SharedItem *shared_make(void);
 extern const struct SharedItem *shared_find(unsigned int, const char *, const char *, const char *);
-#endif
+#endif  /* INCLUDED_conf_shared_h */
