@@ -21,7 +21,7 @@
 
 /*! \file fdlist.h
  * \brief The file descriptor list header.
- * \version $Id: fdlist.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: fdlist.h 10005 2021-06-28 12:10:15Z michael $
  */
 
 #ifndef INCLUDED_fdlist_h
@@ -89,4 +89,4 @@ extern fde_t *fd_close(fde_t *);
 extern void fd_note(fde_t *, const char *, ...);
 extern void close_standard_fds(void);
 extern void close_fds(void);
-#endif
+#endif  /* INCLUDED_fdlist_h */
