@@ -21,7 +21,7 @@
 
 /*! \file hostmask.h
  * \brief A header for the hostmask code.
- * \version $Id: hostmask.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_hostmask_h
@@ -79,6 +79,5 @@ extern void hostmask_expire_temporary(void);
 
 extern struct MaskItem *find_address_conf(const char *, const char *, const struct irc_ssaddr *, const char *);
 extern struct MaskItem *find_dline_conf(const struct irc_ssaddr *);
-extern struct MaskItem *find_conf_by_address(const char *, const struct irc_ssaddr *,
-                                             unsigned int, const char *, const char *, int);
-#endif /* INCLUDED_hostmask_h */
+extern struct MaskItem *find_conf_by_address(const char *, const struct irc_ssaddr *, unsigned int, const char *, const char *, int);
+#endif  /* INCLUDED_hostmask_h */
