@@ -21,7 +21,7 @@
 
 /*! \file ircd.h
  * \brief A header for the ircd startup routines.
- * \version $Id: ircd.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 
@@ -35,9 +35,9 @@
 
 struct SetOptions
 {
-  bool autoconn;      /* autoconn enabled for all servers? */
+  bool autoconn;  /**< autoconn enabled for all servers? */
   unsigned int maxclients;
-  unsigned int floodcount;  /* Number of messages in 'floodtime' seconds */
+  unsigned int floodcount;  /**< Number of messages in 'floodtime' seconds */
   unsigned int floodtime;
   unsigned int joinfloodtime;
   unsigned int joinfloodcount;
@@ -50,37 +50,35 @@ struct SetOptions
  */
 struct ServerStatistics
 {
-  uintmax_t        is_cbs;  /* bytes sent to clients */
-  uintmax_t        is_cbr;  /* bytes received from clients */
-  uintmax_t        is_sbs;  /* bytes sent to servers */
-  uintmax_t        is_sbr;  /* bytes received from servers */
-
-  uintmax_t        is_cti;  /* time spent connected by clients */
-  uintmax_t        is_sti;  /* time spent connected by servers */
-
-  unsigned int    is_cl;   /* number of client connections */
-  unsigned int    is_sv;   /* number of server connections */
-  unsigned int    is_ni;   /* connection but no idea who it was */
-  unsigned int    is_ac;   /* connections accepted */
-  unsigned int    is_ref;  /* accepts refused */
-  unsigned int    is_unco; /* unknown commands */
-  unsigned int    is_wrdi; /* command going in wrong direction */
-  unsigned int    is_unpf; /* unknown prefix */
-  unsigned int    is_empt; /* empty message */
-  unsigned int    is_num;  /* numeric message */
-  unsigned int    is_kill; /* number of kills generated on collisions */
-  unsigned int    is_asuc; /* successful auth requests */
-  unsigned int    is_abad; /* bad auth requests */
+  uintmax_t is_cbs;  /**< Bytes sent to clients */
+  uintmax_t is_cbr;  /**< Bytes received from clients */
+  uintmax_t is_sbs;  /**< Bytes sent to servers */
+  uintmax_t is_sbr;  /**< Bytes received from servers */
+  uintmax_t is_cti;  /**< Time spent connected by clients */
+  uintmax_t is_sti;  /**< Time spent connected by servers */
+  unsigned int is_cl;  /**< Number of client connections */
+  unsigned int is_sv;  /**< Number of server connections */
+  unsigned int is_ni;  /**< Connection but no idea who it was */
+  unsigned int is_ac;  /**< Connections accepted */
+  unsigned int is_ref;  /**< Accepts refused */
+  unsigned int is_unco;  /**< Unknown commands */
+  unsigned int is_wrdi;  /**< Command going in wrong direction */
+  unsigned int is_unpf;  /**< Unknown prefix */
+  unsigned int is_empt;  /**< Empty message */
+  unsigned int is_num;  /**< Numeric message */
+  unsigned int is_kill;  /**< Number of kills generated on collisions */
+  unsigned int is_asuc;  /**< Successful auth requests */
+  unsigned int is_abad;  /**< Bad auth requests */
 };
 
 struct Counter
 {
-  uintmax_t totalrestartcount; /* Total client count ever */
-  unsigned int oper;          /* Opers               */
-  unsigned int invisi;        /* invisible clients   */
-  unsigned int max_loc;       /* MAX local clients   */
-  unsigned int max_tot;       /* MAX global clients  */
-  unsigned int max_loc_con;   /* MAX local connection count (clients + server) */
+  uintmax_t totalrestartcount;  /**< Total client count ever */
+  unsigned int oper;  /**< IRC-operator count */
+  unsigned int invisi;  /**< Invisible clients */
+  unsigned int max_loc;  /**< MAX local clients */
+  unsigned int max_tot;  /**< MAX global clients */
+  unsigned int max_loc_con;  /**< MAX local connection count (clients + server) */
 };
 
 struct ServerState_t
@@ -98,4 +96,4 @@ extern struct ServerStatistics ServerStats;
 extern struct SetOptions GlobalSetOptions;
 extern struct ServerState_t server_state;
 extern struct event event_write_links_file;
-#endif
+#endif  /* INCLUDED_ircd_h */
