@@ -21,7 +21,7 @@
 
 /*! \file isupport.h
  * \brief Contains functions pertaining to RPL_ISUPPORT.
- * \version $Id: isupport.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_isupport_h
@@ -32,4 +32,4 @@ extern void isupport_add(const char *, const char *, int);
 extern void isupport_delete(const char *);
 extern void isupport_rebuild(void);
 extern void isupport_show(struct Client *);
-#endif
+#endif  /* INCLUDED_isupport_h */
