@@ -21,7 +21,7 @@
 
 /*! \file list.h
  * \brief A header for the list manipulation routines.
- * \version $Id: list.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: list.h 10005 2021-06-28 12:10:15Z michael $
  */
 
 #ifndef INCLUDED_list_h
@@ -80,4 +80,4 @@ extern void dlink_move_node(dlink_node *, dlink_list *, dlink_list *);
 extern dlink_node *dlinkFind(dlink_list *, const void *);
 extern dlink_node *dlinkFindDelete(dlink_list *, void *);
 extern dlink_node *make_dlink_node(void);
-#endif
+#endif  /* INCLUDED_list_h */
