@@ -21,13 +21,12 @@
 
 /*! \file listener.h
  * \brief A header for the listener code.
- * \version $Id: listener.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: listener.h 10007 2021-07-22 15:28:05Z michael $
  */
 
 #ifndef INCLUDED_listener_h
 #define INCLUDED_listener_h
 
-#include "ircd_defs.h"
 #include "fdlist.h"
 
 enum
@@ -41,14 +40,14 @@ enum
 
 struct Listener
 {
-  dlink_node node;           /**< Doubly linked list node */
-  bool active;               /**< Current state of listener */
-  fde_t *fd;                 /**< File descriptor */
-  int port;                  /**< Listener IP port */
-  int ref_count;             /**< Number of connection references */
-  struct irc_ssaddr addr;    /**< Holds an IPv6 or IPv4 address */
-  char name[HOSTIPLEN + 1];  /**< Holds an IPv6 or IPv4 address in string representation*/
-  unsigned int flags;        /**< Listener flags (tls, hidden, server, client, defer) */
+  dlink_node node;  /**< Doubly linked list node */
+  bool active;  /**< Current state of listener */
+  fde_t *fd;  /**< File descriptor */
+  int port;  /**< Listener IP port */
+  int ref_count;  /**< Number of connection references */
+  struct irc_ssaddr addr;  /**< Holds an IPv6 or IPv4 address */
+  char *name;  /**< Holds an IPv6 or IPv4 address in string representation*/
+  unsigned int flags;  /**< Listener flags (tls, hidden, server, client, defer) */
 };
 
 extern const dlink_list *listener_get_list(void);
@@ -58,4 +57,4 @@ extern void listener_close_marked(void);
 extern const char *listener_get_name(const struct Listener *);
 extern bool listener_has_flag(const struct Listener *, unsigned int);
 extern void listener_count_memory(unsigned int *, size_t *);
-#endif
+#endif  /* INCLUDED_listener_h */
