@@ -21,7 +21,7 @@
 
 /*! \file send.h
  * \brief A header for the message sending functions.
- * \version $Id: send.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_send_h
@@ -63,26 +63,14 @@ extern void send_queued_write(struct Client *);
 extern void sendto_one(struct Client *, const char *, ...) AFP(2,3);
 extern void sendto_one_numeric(struct Client *, const struct Client *, enum irc_numerics, ...);
 extern void sendto_one_notice(struct Client *, const struct Client *, const char *, ...) AFP(3,4);
-extern void sendto_channel_butone(struct Client *, const struct Client *,
-                                  struct Channel *, unsigned int,
-                                  const char *, ...) AFP(5,6);
-extern void sendto_common_channels_local(struct Client *, bool, unsigned int, unsigned int,
-                                         const char *, ...) AFP(5,6);
-extern void sendto_channel_local(const struct Client *, struct Channel *, unsigned int,
-                                 unsigned int, unsigned int, const char *, ...)  AFP(6,7);
-extern void sendto_server(const struct Client *, const unsigned int,
-                          const unsigned int, const char *, ...) AFP(4,5);
-extern void sendto_match_butone(const struct Client *, const struct Client *,
-                                const char *, int, const char *, ...) AFP(5,6);
-extern void sendto_match_servs(const struct Client *, const char *, unsigned int,
-                               const char *, ...) AFP(4,5);
-extern void sendto_realops_flags(unsigned int, int, int,
-                                 const char *, ...) AFP(4,5);
-extern void sendto_wallops_flags(unsigned int, const struct Client *,
-                                 const char *, ...) AFP(3,4);
+extern void sendto_channel_butone(struct Client *, const struct Client *, struct Channel *, unsigned int, const char *, ...) AFP(5,6);
+extern void sendto_common_channels_local(struct Client *, bool, unsigned int, unsigned int, const char *, ...) AFP(5,6);
+extern void sendto_channel_local(const struct Client *, struct Channel *, unsigned int, unsigned int, unsigned int, const char *, ...) AFP(6,7);
+extern void sendto_server(const struct Client *, const unsigned int, const unsigned int, const char *, ...) AFP(4,5);
+extern void sendto_match_butone(const struct Client *, const struct Client *, const char *, int, const char *, ...) AFP(5,6);
+extern void sendto_match_servs(const struct Client *, const char *, unsigned int, const char *, ...) AFP(4,5);
+extern void sendto_realops_flags(unsigned int, int, int, const char *, ...) AFP(4,5);
+extern void sendto_wallops_flags(unsigned int, const struct Client *, const char *, ...) AFP(3,4);
 extern void sendto_realops_flags_ratelimited(uintmax_t *, const char *, ...) AFP(2,3);
-
-extern void sendto_anywhere(struct Client *, const struct Client *,
-                            const char *,
-                            const char *, ...) AFP(4,5);
+extern void sendto_anywhere(struct Client *, const struct Client *, const char *, const char *, ...) AFP(4,5);
 #endif  /* INCLUDED_send_h */
