@@ -23,10 +23,9 @@
 
 /*! \file tls_openssl.h
  * \brief OpenSSL-specific TLS types
- * \version $Id: tls_openssl.h 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
-
 #ifndef INCLUDED_tls_openssl_h
 #define INCLUDED_tls_openssl_h
 
@@ -37,6 +36,9 @@
 
 #include <openssl/ssl.h>
 #include <openssl/err.h>
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L
+#include <openssl/store.h>
+#endif
 
 typedef SSL * tls_data_t;
 typedef const EVP_MD * tls_md_t;
@@ -46,6 +48,5 @@ typedef struct
   SSL_CTX *server_ctx;
   SSL_CTX *client_ctx;
 } tls_context_t;
-
 #endif  /* HAVE_LIBCRYPTO */
 #endif  /* INCLUDED_tls_openssl_h */
