@@ -21,7 +21,7 @@
 
 /*! \file m_oper.c
  * \brief Includes required functions for processing the OPER command.
- * \version $Id: m_oper.c 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -60,8 +60,6 @@ oper_up(struct Client *source_p, const struct MaskItem *conf)
 
   if (!(old & UMODE_INVISIBLE) && HasUMode(source_p, UMODE_INVISIBLE))
     ++Count.invisi;
-  else if ((old & UMODE_INVISIBLE) && !HasUMode(source_p, UMODE_INVISIBLE))
-    --Count.invisi;
 
   assert(dlinkFind(&oper_list, source_p) == NULL);
   dlinkAdd(source_p, make_dlink_node(), &oper_list);
@@ -214,7 +212,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9858 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
