@@ -21,10 +21,13 @@
 
 /*! \file listener.c
  * \brief Implementation for handling listening sockets.
- * \version $Id: listener.c 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id: listener.c 10003 2021-06-26 15:15:13Z michael $
  */
 
 #include "stdinc.h"
+#include <netinet/in_systm.h>
+#include <netinet/ip.h>
+#include <netinet/tcp.h>
 #include "list.h"
 #include "listener.h"
 #include "client.h"
@@ -56,6 +59,7 @@ listener_make(const int port, const struct irc_ssaddr *addr)
 
   listener->port = port;
   listener->addr = *addr;
+  dlinkAdd(listener, &listener->node, &listener_list);
 
   return listener;
 }
@@ -64,6 +68,7 @@ static void
 listener_free(struct Listener *listener)
 {
   dlinkDelete(&listener->node, &listener_list);
+  xfree(listener->name);
   xfree(listener);
 }
 
@@ -187,12 +192,21 @@ listener_accept_connection(fde_t *F, void *data)
 #endif
 
 static bool
-inetport(struct Listener *listener)
+listener_finalize(struct Listener *listener)
 {
-  socklen_t opt = 1;
+  char buf[HOSTIPLEN + 1];
+  const socklen_t opt = 1;
 
-  getnameinfo((const struct sockaddr *)&listener->addr, listener->addr.ss_len, listener->name,
-              sizeof(listener->name), NULL, 0, NI_NUMERICHOST);
+  getnameinfo((const struct sockaddr *)&listener->addr, listener->addr.ss_len,
+              buf, sizeof(buf), NULL, 0, NI_NUMERICHOST);
+
+  if (buf[0] == ':' && buf[1] == ':')
+  {
+    memmove(buf + 1, buf, sizeof(buf) - 1);
+    buf[0] = '0';
+  }
+
+  listener->name = xstrdup(buf);
 
   /*
    * At first, open a new socket
@@ -205,6 +219,20 @@ inetport(struct Listener *listener)
     return false;
   }
 
+#ifdef IPV6_V6ONLY
+  if (listener->addr.ss.ss_family == AF_INET6 &&
+      IN6_IS_ADDR_UNSPECIFIED(&((struct sockaddr_in6 *)&listener->addr)->sin6_addr))
+  {
+    if (setsockopt(fd, IPPROTO_IPV6, IPV6_V6ONLY, &opt, sizeof(opt)))
+    {
+      report_error(L_ALL, "setting IPV6_V6ONLY for listener %s:%s",
+                   listener_get_name(listener), errno);
+      close(fd);
+      return false;
+    }
+  }
+#endif
+
   if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(opt)))
   {
     report_error(L_ALL, "setting SO_REUSEADDR for listener %s:%s",
@@ -341,7 +369,6 @@ listener_release(struct Listener *listener)
 void
 listener_add(int port, const char *vhost_ip, unsigned int flags)
 {
-  struct Listener *listener;
   struct irc_ssaddr vaddr;
   struct addrinfo hints, *res;
   char portname[PORTNAMELEN + 1];
@@ -354,8 +381,6 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
   if (!(port > 0 && port <= 0xFFFF))
     return;
 
-  memset(&vaddr, 0, sizeof(vaddr));
-
   /* Set up the hints structure */
   memset(&hints, 0, sizeof(hints));
   hints.ai_family = AF_UNSPEC;
@@ -363,28 +388,14 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
   /* Get us ready for a bind() and don't bother doing dns lookup */
   hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
 
-  /* TBD: This makes no sense here at all. Needs to be reworked */
-
   snprintf(portname, sizeof(portname), "%d", port);
-  getaddrinfo("::", portname, &hints, &res);
-  vaddr.ss.ss_family = AF_INET6;
 
+  getaddrinfo("::", portname, &hints, &res);
   assert(res);
 
-  memcpy((struct sockaddr*)&vaddr, res->ai_addr, res->ai_addrlen);
+  memcpy((struct sockaddr *)&vaddr, res->ai_addr, res->ai_addrlen);
   vaddr.ss_len = res->ai_addrlen;
   freeaddrinfo(res);
-#ifdef MAKES_NO_SENSE
-  {
-    struct sockaddr_in *v4 = (struct sockaddr_in*) &vaddr;
-    v4->sin_addr.s_addr = INADDR_ANY;
-    vaddr.ss.ss_family = AF_INET;
-    vaddr.ss_len = sizeof(struct sockaddr_in);
-    v4->sin_port = htons(port);
-  }
-#endif
-
-  snprintf(portname, PORTNAMELEN, "%d", port);
 
   if (!EmptyString(vhost_ip))
   {
@@ -393,7 +404,7 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
 
     assert(res);
 
-    memcpy((struct sockaddr*)&vaddr, res->ai_addr, res->ai_addrlen);
+    memcpy((struct sockaddr *)&vaddr, res->ai_addr, res->ai_addrlen);
     vaddr.ss_len = res->ai_addrlen;
     freeaddrinfo(res);
   }
@@ -406,7 +417,8 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
 
   pass = 0;
 
-  if ((listener = listener_find(port, &vaddr)))
+  struct Listener *listener = listener_find(port, &vaddr);
+  if (listener)
   {
     listener->flags = flags;
 
@@ -419,11 +431,10 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
   else
   {
     listener = listener_make(port, &vaddr);
-    dlinkAdd(listener, &listener->node, &listener_list);
     listener->flags = flags;
   }
 
-  if (inetport(listener) == true)
+  if (listener_finalize(listener) == true)
     listener->active = true;
   else
     listener_close(listener);
