@@ -21,7 +21,7 @@
 
 /*! \file restart.c
  * \brief Functions to allow the ircd to restart.
- * \version $Id: restart.c 9858 2021-01-01 04:43:42Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -46,10 +46,10 @@ server_die(const char *message, bool restart)
   if (restart == true)
   {
     static bool was_here = false;
-    if (was_here == false)
-      was_here = true;
-    else
-      abort(); 
+    if (was_here == true)
+      abort();
+
+    was_here = true;
   } 
 
   if (EmptyString(message))
