@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file user.c
  * \brief User related functions.
- * \version $Id: user.c 9363 2020-04-29 14:06:42Z michael $
+ * \version $Id: user.c 10000 2021-06-26 12:05:38Z michael $
  */
 
 #include "stdinc.h"
@@ -41,14 +41,13 @@
 #include "conf_gecos.h"
 #include "log.h"
 #include "server.h"
-#include "server_capab.h" /* TBR: RHOST compatibility mode */
 #include "send.h"
 #include "memory.h"
 #include "packet.h"
 #include "rng_mt.h"
 #include "misc.h"
 #include "parse.h"
-#include "watch.h"
+#include "monitor.h"
 #include "isupport.h"
 #include "tls.h"
 #include "patchlevel.h"
@@ -58,6 +57,7 @@ static char umode_buffer[UMODE_MAX_STR];
 const struct user_modes *umode_map[256];
 const struct user_modes  umode_tab[] =
 {
+  { 'B', UMODE_BOT          },
   { 'D', UMODE_DEAF         },
   { 'F', UMODE_FARCONNECT   },
   { 'G', UMODE_SOFTCALLERID },
@@ -67,11 +67,10 @@ const struct user_modes  umode_tab[] =
   { 'S', UMODE_SECURE       },
   { 'W', UMODE_WEBIRC       },
   { 'a', UMODE_ADMIN        },
-  { 'b', UMODE_BOTS         },
   { 'c', UMODE_CCONN        },
   { 'd', UMODE_DEBUG        },
   { 'e', UMODE_EXTERNAL     },
-  { 'f', UMODE_FULL         },
+  { 'f', UMODE_FLOOD        },
   { 'g', UMODE_CALLERID     },
   { 'i', UMODE_INVISIBLE    },
   { 'j', UMODE_REJ          },
@@ -83,7 +82,6 @@ const struct user_modes  umode_tab[] =
   { 'q', UMODE_HIDEIDLE     },
   { 'r', UMODE_REGISTERED   },
   { 's', UMODE_SERVNOTICE   },
-  { 'u', UMODE_UNAUTH       },
   { 'w', UMODE_WALLOP       },
   { 'y', UMODE_SPY          },
   { '\0', 0 }
@@ -202,11 +200,10 @@ report_and_set_user_flags(struct Client *client, const struct MaskItem *conf)
 static void
 introduce_client(struct Client *client)
 {
-  dlink_node *node;
   char buf[UMODE_MAX_STR] = "";
 
   send_umode(client, MyConnect(client), 0, buf);
-  watch_check_hash(client, RPL_LOGON);
+  monitor_signon(client);
 
   if (buf[0] == '\0')
   {
@@ -214,36 +211,14 @@ introduce_client(struct Client *client)
     buf[1] = '\0';
   }
 
-  DLINK_FOREACH(node, local_server_list.head)
-  {
-    struct Client *server = node->data;
+  sendto_server(client, 0, 0, ":%s UID %s %u %ju %s %s %s %s %s %s %s :%s",
+                client->servptr->id, client->name, client->hopcount + 1,
+                client->tsinfo, buf, client->username, client->host,
+                client->realhost, client->sockhost, client->id,
+                client->account, client->info);
 
-    if (server == client->from)
-      continue;
-
-    /* TBR: compatibility mode */
-    if (IsCapable(server, CAPAB_RHOST))
-      sendto_one(server, ":%s UID %s %u %ju %s %s %s %s %s %s %s :%s",
-                 client->servptr->id,
-                 client->name, client->hopcount+1,
-                 client->tsinfo,
-                 buf, client->username, client->host, client->realhost,
-                 client->sockhost, client->id,
-                 client->account,
-                 client->info);
-    else
-      sendto_one(server, ":%s UID %s %u %ju %s %s %s %s %s %s :%s",
-                 client->servptr->id,
-                 client->name, client->hopcount+1,
-                 client->tsinfo,
-                 buf, client->username, client->host,
-                 client->sockhost, client->id,
-                 client->account,
-                 client->info);
-
-    if (!EmptyString(client->certfp))
-      sendto_one(server, ":%s CERTFP %s", client->id, client->certfp);
-  }
+  if (!EmptyString(client->tls_certfp))
+    sendto_server(client, 0, 0, ":%s CERTFP %s", client->id, client->tls_certfp);
 }
 
 /* user_welcome()
@@ -260,8 +235,10 @@ user_welcome(struct Client *client)
   if (HasFlag(client, FLAGS_TLS))
   {
     AddUMode(client, UMODE_SECURE);
+
+    client->tls_cipher = xstrdup(tls_get_cipher(&client->connection->fd->tls));
     sendto_one_notice(client, &me, ":*** Connected securely via %s",
-                      tls_get_cipher(&client->connection->fd->tls));
+                      client->tls_cipher);
   }
 
   sendto_one_numeric(client, &me, RPL_WELCOME, ConfigServerInfo.network_name,
@@ -315,7 +292,7 @@ register_local_user(struct Client *client)
 
   if (!HasFlag(client, FLAGS_GOTID))
   {
-    char username[USERLEN + 1] = "";
+    char username[USERLEN + 1];
     unsigned int i = 0;
 
     if (IsNeedIdentd(conf))
@@ -359,9 +336,6 @@ register_local_user(struct Client *client)
    */
   report_and_set_user_flags(client, conf);
 
-  if (IsDead(client))
-    return;
-
   /*
    * Limit clients -
    * We want to be able to have servers and F-line clients
@@ -373,7 +347,7 @@ register_local_user(struct Client *client)
   if ((dlink_list_length(&local_client_list) >= GlobalSetOptions.maxclients + MAX_BUFFER) ||
       (dlink_list_length(&local_client_list) >= GlobalSetOptions.maxclients && !HasFlag(client, FLAGS_NOLIMIT)))
   {
-    sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Too many clients, rejecting %s[%s].",
                          client->name, client->host);
     ++ServerStats.is_ref;
@@ -383,7 +357,7 @@ register_local_user(struct Client *client)
 
   if (valid_username(client->username, true) == false)
   {
-    char buf[IRCD_BUFSIZE] = "";
+    char buf[sizeof("Invalid username []") + sizeof(client->username)];
 
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Invalid username: %s (%s@%s)",
@@ -563,19 +537,19 @@ valid_username(const char *username, bool local)
 
   if (local)
   {
-    unsigned int dots = 0;
+    unsigned int special = 0;
 
-    while (*++p)
+    while (*p)
     {
-      if (*p == '.' && ConfigGeneral.dots_in_ident)
+      if (*p == '-' || *p == '_' || *p == '.')
       {
-        if (++dots > ConfigGeneral.dots_in_ident)
-          return false;
-        if (!IsUserChar(*(p + 1)))
+        if (ConfigGeneral.specials_in_ident < ++special)
           return false;
       }
-      else if (!IsUserChar(*p))
+      else if (!IsUser2Char(*p))
         return false;
+
+      ++p;
     }
   }
   else
@@ -718,19 +692,19 @@ user_set_hostmask(struct Client *client, const char *hostname)
     int len = 0;
     const struct ChannelMember *member = node->data;
 
-    if (has_member_flags(member, CHFL_CHANOP))
+    if (member_has_flags(member, CHFL_CHANOP) == true)
     {
       *p++ = 'o';
       len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", client->name);
     }
 
-    if (has_member_flags(member, CHFL_HALFOP))
+    if (member_has_flags(member, CHFL_HALFOP) == true)
     {
       *p++ = 'h';
       len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", client->name);
     }
 
-    if (has_member_flags(member, CHFL_VOICE))
+    if (member_has_flags(member, CHFL_VOICE) == true)
     {
       *p++ = 'v';
       len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", client->name);
